![alt text](https://github.com/labsyspharm/cylinter/blob/master/docs/logo.png?raw=true)

# An Interactive Image Segmentation Filter for Multiplex Microscopy.

CyLinter identifies and removes cell segmentation instances (i.e. cells) in multiplexed whole tissue and tissue microarray images corrupted by optical and/or image preprocessing (e.g. stitching, registration, segmentation) artifacts. The tool comprises a set of user-guided, quality control (QC) modules instantiated as a configurable [Python](https://www.python.org) Class; module results are cached to allow for dynamic restarts and iterative QC strategies. The tool is used to clean image-derived, single-cell data prior to downstream analysis.

CyLinter development is led by [Greg Baker](https://github.com/gjbaker) at [Laboratory of Systems Pharmacology](https://hits.harvard.edu/the-program/laboratory-of-systems-pharmacology/about/), Harvard Medical School.

**Funding:** This work is supported by the following:

* *NIH grant U54CA225088: Systems Pharmacology of Therapeutic and Adverse Responses to Immune Checkpoint and Small Molecule Drugs*
* Ludwig Center at Harvard Medical School and the Ludwig Cancer Research Foundation

**Instructions:** https://labsyspharm.github.io/cylinter/
